@@ -10,7 +10,7 @@ shinyUI(fluidPage(
         tags$style(type = 'text/css', '.popover {max-width: 100%;}')
       ),
       helpText('This Shiny app uses the function', code('tidy_source()'),
-               'in the', a(href = 'http://yihui.org/formatR', strong('formatR')),
+               'in the', a(href = 'https://yihui.org/formatR/', strong('formatR')),
                sprintf('(>= v%s)', packageVersion('formatR')),
                'package to reformat R code in the text box on the right.',
                a(list(icon('hand-o-right'), 'demo'), class = 'btn btn-small btn-info',
@@ -20,8 +20,9 @@ shinyUI(fluidPage(
       checkboxInput('arg_assign', 'Replace = with <-', FALSE),
       checkboxInput('arg_brace', 'Put { on a new line', FALSE),
       numericInput ('arg_indent', 'Number of spaces for indentation', 4, min = 0),
-      numericInput ('arg_width', 'Minimum line width', 70, min = 20, max = 500),
-      submitButton ('Tidy My Code', icon('toggle-right'))
+      radioButtons('width_type', 'Line width type', c('minimum', 'maximum'), inline = TRUE),
+      numericInput ('arg_width', 'Line width value', 70, min = 20, max = 500),
+      submitButton ('Format My Code', icon('toggle-right'))
     ),
     mainPanel(
       tags$textarea(
@@ -31,10 +32,12 @@ shinyUI(fluidPage(
       ),
       tags$textarea(
         id = 'demo', style = 'display: none;',
-        paste(
+        paste(c(
           readLines(system.file('format', 'messy.R', package = 'formatR')),
-          collapse = '\n'
-        )
+          '',
+          '# and pipes on a single line',
+          'mtcars %>% subset(am==0) %>% lm(mpg~hp, data=.)'
+        ), collapse = '\n')
       )
     )
   )
